@@ -22,9 +22,9 @@ Functions:
 # Import
 # =============================================================================
 
-
 from datetime import datetime, timezone, timedelta
 from typing import List, Union, Tuple
+from roguewave.tools.time import to_datetime_utc
 
 
 # Model private variables
@@ -114,6 +114,94 @@ class ModelTimeConfiguration:
         return interval
 
 
+class TimeSlice:
+    def __init__(self, start_time:datetime, end_time:datetime):
+        self.start_time = to_datetime_utc(start_time)
+        self.end_time = to_datetime_utc(end_time)
+
+    def time_base(self, time_configuration:ModelTimeConfiguration)\
+            -> List[Tuple[datetime, timedelta]]:
+        pass
+
+
+class TimeSliceForecast(TimeSlice):
+    def __init__(self, init_time:datetime, duration:timedelta):
+        """
+        Timeslice for a single forecast
+        :param init_time: init time of forecast (datetime)
+        :param duration: forecast length (time delta)
+        """
+        self.init_time = to_datetime_utc(init_time)
+        self.duration = duration
+        super().__init__(self.init_time,self.init_time+duration)
+
+    def time_base(self, time_configuration:ModelTimeConfiguration):
+        return timebase_forecast(
+            init_time=self.init_time,
+            duration=self.duration,
+            time_configuration=time_configuration)
+
+
+class TimeSliceLead(TimeSlice):
+    def __init__(self,start_time:datetime,end_time:datetime,
+                 lead_time:timedelta,exact=False):
+        """
+        Slice at constant lead time
+        :param start_time: start time of period of interest (datetime)
+        :param end_time: end time of period of interest (datetime)
+        :param lead_time: lead time (timedelta) of interest.
+        :param exact: boolean. Do we want data only exactly at the given lead
+            time, or as close as possible
+        """
+        super().__init__(start_time,end_time)
+        self.lead_time = lead_time
+        self.exact = exact
+
+    def time_base(self, time_configuration:ModelTimeConfiguration):
+        return timebase_lead(
+            start_time = self.start_time,
+            end_time = self.end_time,
+            lead_time=self.lead_time,
+            time_configuration=time_configuration,
+            exact=self.exact)
+
+
+class TimeSliceAnalysis(TimeSlice):
+    def __init__(self,start_time:datetime,end_time:datetime):
+        """
+        Analysis time
+        :param start_time: start time of period of interest (datetime)
+        :param end_time: end time of period of interest (datetime)
+        """
+        super().__init__(start_time,end_time)
+
+    def time_base(self, time_configuration:ModelTimeConfiguration):
+        return timebase_lead(
+            start_time = self.start_time,
+            end_time = self.end_time,
+            lead_time=timedelta(hours=0),
+            time_configuration=time_configuration,
+            exact=False)
+
+
+class TimeSliceEvaluation(TimeSlice):
+    def __init__(self, evaluation_time:datetime, maximum_lead_time:timedelta):
+        """
+        All data for a constant point in time
+        :param evaluation_time: evaluation point (datetime)
+        :param maximum_lead_time:  maximum lead time considered (timedelta)
+        """
+        super().__init__(start_time=evaluation_time,end_time=evaluation_time)
+        self.evaluation_time = evaluation_time
+        self.maximum_lead_time = maximum_lead_time
+
+    def time_base(self, time_configuration:ModelTimeConfiguration):
+        return timebase_evaluation(
+            evaluation_time=self.evaluation_time,
+            maximum_lead_time=self.maximum_lead_time,
+            time_configuration=time_configuration)
+
+
 # Main Public Functions
 # =============================================================================
 def find_closet_init_time(evaluation_time: datetime,
