@@ -8,31 +8,34 @@ Authors: Pieter Bart Smit
 """
 
 import numpy
-from .wavespectrum import WaveSpectrum, WaveSpectrumInput
-from roguewave.tools import datetime_to_iso_time_string
+from .wavespectrum import WaveSpectrum
 from typing import List, Union
-from datetime import timedelta
+from datetime import datetime
 
 
-class WaveSpectrum1DInput(WaveSpectrumInput):
-    a1: Union[List[float], numpy.ndarray]
-    b1: Union[List[float], numpy.ndarray]
-    a2: Union[List[float], numpy.ndarray]
-    b2: Union[List[float], numpy.ndarray]
-
 
 class WaveSpectrum1D(WaveSpectrum):
     spectral_density_units = 'm**2/Hertz'
 
     def __init__(self,
-                 wave_spectrum1D_input: WaveSpectrum1DInput
+                 frequency: Union[List[float], numpy.ndarray],
+                 varianceDensity: Union[List[float], numpy.ndarray],
+                 a1: Union[List[float], numpy.ndarray],
+                 b1: Union[List[float], numpy.ndarray],
+                 a2: Union[List[float], numpy.ndarray],
+                 b2: Union[List[float], numpy.ndarray],
+                 timestamp: Union[str, datetime, int, float],
+                 latitude: Union[float, None],
+                 longitude: Union[float, None],
+                 **kwargs
                  ):
-        super().__init__(wave_spectrum1D_input)
-        self._a1 = numpy.array(wave_spectrum1D_input['a1'])
-        self._b1 = numpy.array(wave_spectrum1D_input['b1'])
-        self._b2 = numpy.array(wave_spectrum1D_input['b2'])
-        self._a2 = numpy.array(wave_spectrum1D_input['a2'])
-        self._e = numpy.array(wave_spectrum1D_input['varianceDensity'])
+        super().__init__(frequency=frequency, varianceDensity=varianceDensity,
+                         timestamp=timestamp,latitude=latitude,longitude=longitude)
+        self._a1 = numpy.array(a1)
+        self._b1 = numpy.array(b1)
+        self._b2 = numpy.array(b2)
+        self._a2 = numpy.array(a2)
+        self._e = numpy.array(self.variance_density)
 
     @WaveSpectrum.variance_density.setter
     def variance_density(self,val:numpy.ndarray):
@@ -46,21 +49,21 @@ class WaveSpectrum1D(WaveSpectrum):
             self.variance_density[range] * self.frequency[range] ** power,
             self.frequency[range])
 
-    def _create_wave_spectrum_input(self) -> WaveSpectrum1DInput:
-        return WaveSpectrum1DInput(
-            frequency=self.frequency,
-            varianceDensity=self.variance_density,
-            timestamp=datetime_to_iso_time_string(self.timestamp),
-            latitude=self.latitude,
-            longitude=self.longitude,
-            a1=self.a1,
-            b1=self.b1,
-            a2=self.a2,
-            b2=self.b2
-        )
+    def _create_wave_spectrum_input(self) -> dict:
+        return {
+            "frequency": self.frequency,
+            "varianceDensity": self.variance_density,
+            "a1": self.a1,
+            "b1": self.b1,
+            "a2": self.a2,
+            "b2": self.b2,
+            "timestamp": self.timestamp,
+            "latitude": self.latitude,
+            "longitude": self.longitude,
+        }
 
     def copy(self) -> "WaveSpectrum1D":
-        input = WaveSpectrum1DInput(
+        return WaveSpectrum1D(
             frequency=self.frequency.copy(),
             varianceDensity=self.variance_density.copy(),
             timestamp=self.timestamp,
@@ -69,9 +72,7 @@ class WaveSpectrum1D(WaveSpectrum):
             a1=self.a1,
             b1=self.b1,
             a2=self.a2,
-            b2=self.b2
-        )
-        return WaveSpectrum1D(input)
+            b2=self.b2)
 
     def __add__(self, other:"WaveSpectrum1D")->"WaveSpectrum1D":
         spectrum = self.copy()
@@ -92,7 +93,7 @@ class WaveSpectrum1D(WaveSpectrum):
 
 
 def empty_spectrum1D_like(spectrum: WaveSpectrum1D) -> WaveSpectrum1D:
-    input = WaveSpectrum1DInput(
+    return WaveSpectrum1D(
         frequency=spectrum.frequency.copy(),
         varianceDensity=numpy.zeros_like(spectrum.variance_density),
         timestamp=spectrum.timestamp,
@@ -103,6 +104,5 @@ def empty_spectrum1D_like(spectrum: WaveSpectrum1D) -> WaveSpectrum1D:
         a2=list(spectrum.a2),
         b2=list(spectrum.b2)
     )
-    return WaveSpectrum1D(input)
 
 
